@@ -48,15 +48,7 @@
 #include "doc.h"
 #include "bus.h"
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
- #if defined(__APPLE__) || defined(Q_OS_MAC)
-  #include "audiocapture_portaudio.h"
- #elif defined(WIN32) || defined (Q_OS_WIN)
-  #include "audiocapture_wavein.h"
- #else
-  #include "audiocapture_alsa.h"
- #endif
-#elif QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
  #include "audiocapture_qt5.h"
 #else
  #include "audiocapture_qt6.h"
@@ -64,7 +56,7 @@
 
 Doc::Doc(QObject* parent, int universes)
     : QObject(parent)
-    , m_wsPath("")
+    , m_workspacePath("")
     , m_fixtureDefCache(new QLCFixtureDefCache)
     , m_modifiersCache(new QLCModifiersCache)
     , m_rgbScriptsCache(new RGBScriptsCache(this))
@@ -116,6 +108,9 @@ Doc::~Doc()
 
     delete m_fixtureDefCache;
     m_fixtureDefCache = NULL;
+
+    delete m_rgbScriptsCache;
+    m_rgbScriptsCache = NULL;
 }
 
 void Doc::clearContents()
@@ -194,12 +189,12 @@ void Doc::clearContents()
 
 void Doc::setWorkspacePath(QString path)
 {
-    m_wsPath = path;
+    m_workspacePath = path;
 }
 
-QString Doc::getWorkspacePath() const
+QString Doc::workspacePath() const
 {
-    return m_wsPath;
+    return m_workspacePath;
 }
 
 QString Doc::normalizeComponentPath(const QString& filePath) const
@@ -209,9 +204,9 @@ QString Doc::normalizeComponentPath(const QString& filePath) const
 
     QFileInfo f(filePath);
 
-    if (f.absolutePath().startsWith(getWorkspacePath()))
+    if (f.absolutePath().startsWith(workspacePath()))
     {
-        return QDir(getWorkspacePath()).relativeFilePath(f.absoluteFilePath());
+        return QDir(workspacePath()).relativeFilePath(f.absoluteFilePath());
     }
     else
     {
@@ -224,7 +219,7 @@ QString Doc::denormalizeComponentPath(const QString& filePath) const
     if (filePath.isEmpty())
         return filePath;
 
-    return QFileInfo(QDir(getWorkspacePath()), filePath).absoluteFilePath();
+    return QFileInfo(QDir(workspacePath()), filePath).absoluteFilePath();
 }
 
 /*****************************************************************************
@@ -277,16 +272,8 @@ QSharedPointer<AudioCapture> Doc::audioInputCapture()
     {
         qDebug() << "Creating new audio capture";
         m_inputCapture = QSharedPointer<AudioCapture>(
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-#if defined(__APPLE__) || defined(Q_OS_MAC)
-            new AudioCapturePortAudio()
-#elif defined(WIN32) || defined (Q_OS_WIN)
-            new AudioCaptureWaveIn()
-#else
-            new AudioCaptureAlsa()
-#endif
-#elif QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-            new AudioCaptureQt6()
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+            new AudioCaptureQt5()
 #else
             new AudioCaptureQt6()
 #endif
@@ -589,6 +576,13 @@ bool Doc::replaceFixtures(QList<Fixture*> newFixturesList)
         newFixture->setForcedHTPChannels(fixture->forcedHTPChannels());
         newFixture->setForcedLTPChannels(fixture->forcedLTPChannels());
 
+        for (quint32 s = 0; s < fixture->channels(); s++)
+        {
+            ChannelModifier *chMod = fixture->channelModifier(s);
+            if (chMod != NULL)
+                newFixture->setChannelModifier(s, chMod);
+        }
+
         m_fixtures.insert(id, newFixture);
         m_fixturesListCacheUpToDate = false;
 
@@ -800,10 +794,7 @@ bool Doc::deleteFixtureGroup(quint32 id)
 
 FixtureGroup* Doc::fixtureGroup(quint32 id) const
 {
-    if (m_fixtureGroups.contains(id) == true)
-        return m_fixtureGroups[id];
-    else
-        return NULL;
+    return m_fixtureGroups.value(id, NULL);
 }
 
 QList <FixtureGroup*> Doc::fixtureGroups() const
@@ -898,10 +889,7 @@ bool Doc::moveChannelGroup(quint32 id, int direction)
 
 ChannelsGroup* Doc::channelsGroup(quint32 id) const
 {
-    if (m_channelsGroups.contains(id) == true)
-        return m_channelsGroups[id];
-    else
-        return NULL;
+    return m_channelsGroups.value(id, NULL);
 }
 
 QList <ChannelsGroup*> Doc::channelsGroups() const
@@ -977,10 +965,7 @@ bool Doc::deletePalette(quint32 id)
 
 QLCPalette *Doc::palette(quint32 id) const
 {
-    if (m_palettes.contains(id) == true)
-        return m_palettes[id];
-    else
-        return NULL;
+    return m_palettes.value(id, NULL);
 }
 
 QList<QLCPalette *> Doc::palettes() const
@@ -1104,10 +1089,7 @@ bool Doc::deleteFunction(quint32 id)
 
 Function* Doc::function(quint32 id) const
 {
-    if (m_functions.contains(id) == true)
-        return m_functions[id];
-    else
-        return NULL;
+    return m_functions.value(id, NULL);
 }
 
 quint32 Doc::nextFunctionID()
