@@ -47,8 +47,8 @@ class MonitorProperties;
  * @{
  */
 
-#define KXMLQLCEngine QString("Engine")
-#define KXMLQLCStartupFunction QString("Autostart")
+#define KXMLQLCEngine QStringLiteral("Engine")
+#define KXMLQLCStartupFunction QStringLiteral("Autostart")
 
 class Doc : public QObject
 {
@@ -81,7 +81,7 @@ public:
     void setWorkspacePath(QString path);
 
     /** Retrieve the current workspace absolute path */
-    QString getWorkspacePath() const;
+    QString workspacePath() const;
 
     /** If filePath is in the workspace directory or in one of its subdirectories,
      *  return path relative to the workspace directory.
@@ -100,7 +100,7 @@ public:
     QString denormalizeComponentPath(const QString& filePath) const;
 
 private:
-    QString m_wsPath;
+    QString m_workspacePath;
 
 signals:
     /** Emitted when clearContents() is called, before actually doing anything. */
@@ -268,7 +268,7 @@ public:
     /**
      * Replace the whole fixtures list with a new one.
      * This is done by remapping. Note that no signal is emitted to
-     * avoid loosing scenes and all the stuff connected to fixtures.
+     * avoid losing scenes and all the stuff connected to fixtures.
      * The caller must be aware on this and reassign all the QLC+ project
      * data previously created.
      *
@@ -537,7 +537,7 @@ public:
     quint32 nextFunctionID();
 
     /**
-     * Set the ID of a function to start everytime QLC+ goes
+     * Set the ID of a function to start every time QLC+ goes
      * in operate mode
      *
      * @param fid The ID of the function
