@@ -557,10 +557,7 @@ void Fixture::setChannelModifier(quint32 idx, ChannelModifier *mod)
 
 ChannelModifier *Fixture::channelModifier(quint32 idx)
 {
-    if (m_channelModifiers.contains(idx))
-        return m_channelModifiers[idx];
-
-    return NULL;
+    return m_channelModifiers.value(idx, NULL);
 }
 
 /*********************************************************************
@@ -1246,7 +1243,7 @@ bool Fixture::loadXML(QXmlStreamReader &xmlDoc, Doc *doc,
             QString man(manufacturer);
             QString mod(model);
             QString path = QString("%1%2%3-%4%5")
-                    .arg(doc->getWorkspacePath()).arg(QDir::separator())
+                    .arg(doc->workspacePath()).arg(QDir::separator())
                     .arg(man.replace(" ", "-")).arg(mod.replace(" ", "-")).arg(KExtFixture);
 
             qDebug() << "Fixture not found. Fallback to:" << path;
@@ -1428,9 +1425,8 @@ bool Fixture::saveXML(QXmlStreamWriter *doc) const
         doc->writeTextElement(KXMLFixtureForcedLTP, list);
     }
 
-    if (m_channelModifiers.isEmpty() == false)
     {
-        QHashIterator<quint32, ChannelModifier *> it(m_channelModifiers);
+        QMapIterator<quint32, ChannelModifier *> it(m_channelModifiers);
         while (it.hasNext())
         {
             it.next();
