@@ -30,8 +30,8 @@
 
 class QXmlStreamReader;
 class QXmlStreamWriter;
-class QLCInputSource;
 class QElapsedTimer;
+class QLCInputSource;
 class QLCIOPlugin;
 class OutputPatch;
 class InputPatch;
@@ -42,10 +42,10 @@ class Doc;
  * @{
  */
 
-#define KXMLIOMap               QString("InputOutputMap")
-#define KXMLIOBeatGenerator     QString("BeatGenerator")
-#define KXMLIOBeatType          QString("BeatType")
-#define KXMLIOBeatsPerMinute    QString("BPM")
+#define KXMLIOMap               QStringLiteral("InputOutputMap")
+#define KXMLIOBeatGenerator     QStringLiteral("BeatGenerator")
+#define KXMLIOBeatType          QStringLiteral("BeatType")
+#define KXMLIOBeatsPerMinute    QStringLiteral("BPM")
 
 class InputOutputMap : public QObject
 {
@@ -65,7 +65,7 @@ public:
      * @param doc The QLC+ project reference
      * @param universes Number of universes
      */
-    InputOutputMap(Doc* doc, quint32 universesCount);
+    InputOutputMap(const Doc* doc, quint32 universesCount);
 
     /**
      * Destroy a InputOutputMap object
@@ -73,8 +73,7 @@ public:
     ~InputOutputMap();
 
 private:
-    /** Get the doc object */
-    Doc* doc() const;
+    const Doc *m_doc;
 
     /*********************************************************************
      * Blackout
@@ -575,6 +574,8 @@ private:
     /** List that contains all available profiles */
     QList <QLCInputProfile*> m_profiles;
 
+    bool m_localProfilesLoaded;
+
     /*********************************************************************
      * Beats
      *********************************************************************/
