@@ -20,7 +20,6 @@
 
 #include <QDebug>
 #include <QSettings>
-#include <QElapsedTimer>
 #include <QMutexLocker>
 
 #if defined(WIN32) || defined(Q_OS_WIN)
@@ -66,7 +65,6 @@ MasterTimer::MasterTimer(Doc* doc)
     , m_currentBPM(120)
     , m_beatTimeDuration(500)
     , m_beatRequested(false)
-    , m_beatTimer(new QElapsedTimer())
     , m_lastBeatOffset(0)
 {
     Q_ASSERT(doc != NULL);
@@ -87,8 +85,6 @@ MasterTimer::~MasterTimer()
 
     delete d_ptr;
     d_ptr = NULL;
-
-    delete m_beatTimer;
 }
 
 void MasterTimer::start()
@@ -117,7 +113,7 @@ void MasterTimer::timerTick()
     {
         case Internal:
         {
-            int elapsedTime = qRound((double)m_beatTimer->nsecsElapsed() / 1000000) + m_lastBeatOffset;
+            int elapsedTime = qRound((double)m_beatTimer.nsecsElapsed() / 1000000) + m_lastBeatOffset;
             //qDebug() << "Elapsed beat:" << elapsedTime;
             if (elapsedTime >= m_beatTimeDuration)
             {
@@ -128,7 +124,7 @@ void MasterTimer::timerTick()
                 // milliseconds, otherwise it will generate an unpleasant drift
                 //qDebug() << "Elapsed:" << elapsedTime << ", delta:" << elapsedTime - m_beatTimeDuration;
                 m_lastBeatOffset = elapsedTime - m_beatTimeDuration;
-                m_beatTimer->restart();
+                m_beatTimer.restart();
 
                 // inform the listening classes that a beat is happening
                 emit beat();
@@ -363,7 +359,7 @@ void MasterTimer::setBeatSourceType(MasterTimer::BeatsSourceType type)
     // alright, this causes a time drift of maximum 1ms per beat
     // but at the moment I am not looking for a better solution
     m_beatTimeDuration = 60000 / m_currentBPM;
-    m_beatTimer->restart();
+    m_beatTimer.restart();
 
     m_beatSourceType = type;
 }
@@ -380,7 +376,7 @@ void MasterTimer::requestBpmNumber(int bpm)
 
     m_currentBPM = bpm;
     m_beatTimeDuration = 60000 / m_currentBPM;
-    m_beatTimer->restart();
+    m_beatTimer.restart();
 
     emit bpmNumberChanged(bpm);
 }
@@ -397,7 +393,7 @@ int MasterTimer::beatTimeDuration() const
 
 int MasterTimer::timeToNextBeat() const
 {
-    return m_beatTimeDuration - m_beatTimer->elapsed();
+    return m_beatTimeDuration - m_beatTimer.elapsed();
 }
 
 int MasterTimer::nextBeatTimeOffset() const
