@@ -30,31 +30,31 @@
 #include "qlcchannel.h"
 #include "qlccapability.h"
 
-#define KXMLQLCChannelGroupIntensity   QString("Intensity")
-#define KXMLQLCChannelGroupColour      QString("Colour")
-#define KXMLQLCChannelGroupGobo        QString("Gobo")
-#define KXMLQLCChannelGroupPrism       QString("Prism")
-#define KXMLQLCChannelGroupShutter     QString("Shutter")
-#define KXMLQLCChannelGroupBeam        QString("Beam")
-#define KXMLQLCChannelGroupSpeed       QString("Speed")
-#define KXMLQLCChannelGroupEffect      QString("Effect")
-#define KXMLQLCChannelGroupPan         QString("Pan")
-#define KXMLQLCChannelGroupTilt        QString("Tilt")
-#define KXMLQLCChannelGroupMaintenance QString("Maintenance")
-#define KXMLQLCChannelGroupNothing     QString("Nothing")
+#define KXMLQLCChannelGroupIntensity   QStringLiteral("Intensity")
+#define KXMLQLCChannelGroupColour      QStringLiteral("Colour")
+#define KXMLQLCChannelGroupGobo        QStringLiteral("Gobo")
+#define KXMLQLCChannelGroupPrism       QStringLiteral("Prism")
+#define KXMLQLCChannelGroupShutter     QStringLiteral("Shutter")
+#define KXMLQLCChannelGroupBeam        QStringLiteral("Beam")
+#define KXMLQLCChannelGroupSpeed       QStringLiteral("Speed")
+#define KXMLQLCChannelGroupEffect      QStringLiteral("Effect")
+#define KXMLQLCChannelGroupPan         QStringLiteral("Pan")
+#define KXMLQLCChannelGroupTilt        QStringLiteral("Tilt")
+#define KXMLQLCChannelGroupMaintenance QStringLiteral("Maintenance")
+#define KXMLQLCChannelGroupNothing     QStringLiteral("Nothing")
 
-#define KXMLQLCChannelColourGeneric    QString("Generic")
-#define KXMLQLCChannelColourRed        QString("Red")
-#define KXMLQLCChannelColourGreen      QString("Green")
-#define KXMLQLCChannelColourBlue       QString("Blue")
-#define KXMLQLCChannelColourCyan       QString("Cyan")
-#define KXMLQLCChannelColourMagenta    QString("Magenta")
-#define KXMLQLCChannelColourYellow     QString("Yellow")
-#define KXMLQLCChannelColourAmber      QString("Amber")
-#define KXMLQLCChannelColourWhite      QString("White")
-#define KXMLQLCChannelColourUV         QString("UV")
-#define KXMLQLCChannelColourLime       QString("Lime")
-#define KXMLQLCChannelColourIndigo     QString("Indigo")
+#define KXMLQLCChannelColourGeneric    QStringLiteral("Generic")
+#define KXMLQLCChannelColourRed        QStringLiteral("Red")
+#define KXMLQLCChannelColourGreen      QStringLiteral("Green")
+#define KXMLQLCChannelColourBlue       QStringLiteral("Blue")
+#define KXMLQLCChannelColourCyan       QStringLiteral("Cyan")
+#define KXMLQLCChannelColourMagenta    QStringLiteral("Magenta")
+#define KXMLQLCChannelColourYellow     QStringLiteral("Yellow")
+#define KXMLQLCChannelColourAmber      QStringLiteral("Amber")
+#define KXMLQLCChannelColourWhite      QStringLiteral("White")
+#define KXMLQLCChannelColourUV         QStringLiteral("UV")
+#define KXMLQLCChannelColourLime       QStringLiteral("Lime")
+#define KXMLQLCChannelColourIndigo     QStringLiteral("Indigo")
 
 QLCChannel::QLCChannel(QObject *parent)
     : QObject(parent)
