@@ -19,6 +19,7 @@
 
 #include <QXmlStreamReader>
 #include <QXmlStreamWriter>
+#include <unistd.h>
 #include <QString>
 #include <QDebug>
 #include <QMap>
@@ -28,16 +29,16 @@
 #include "qlcchannel.h"
 #include "qlcfile.h"
 
-#define KXMLQLCInputProfileTypeMidi "MIDI"
-#define KXMLQLCInputProfileTypeOs2l "OS2L"
-#define KXMLQLCInputProfileTypeOsc "OSC"
-#define KXMLQLCInputProfileTypeHid "HID"
-#define KXMLQLCInputProfileTypeDmx "DMX"
-#define KXMLQLCInputProfileTypeEnttec "Enttec"
+#define KXMLQLCInputProfileTypeMidi QStringLiteral("MIDI")
+#define KXMLQLCInputProfileTypeOs2l QStringLiteral("OS2L")
+#define KXMLQLCInputProfileTypeOsc QStringLiteral("OSC")
+#define KXMLQLCInputProfileTypeHid QStringLiteral("HID")
+#define KXMLQLCInputProfileTypeDmx QStringLiteral("DMX")
+#define KXMLQLCInputProfileTypeEnttec QStringLiteral("Enttec")
 
-#define KXMLQLCInputProfileValue "Value"
-#define KXMLQLCInputProfileLabel "Label"
-#define KXMLQLCInputProfileColorRGB "RGB"
+#define KXMLQLCInputProfileValue QStringLiteral("Value")
+#define KXMLQLCInputProfileLabel QStringLiteral("Label")
+#define KXMLQLCInputProfileColorRGB QStringLiteral("RGB")
 
 /****************************************************************************
  * Initialization
@@ -298,7 +299,7 @@ bool QLCInputProfile::remapChannel(QLCInputChannel* ich, quint32 number)
     quint32 old = channelNumber(ich);
     if (old != QLCChannel::invalid() && m_channels.contains(number) == false)
     {
-        m_channels.take(old);
+        m_channels.remove(old);
         insertChannel(number, ich);
         return true;
     }
@@ -310,10 +311,7 @@ bool QLCInputProfile::remapChannel(QLCInputChannel* ich, quint32 number)
 
 QLCInputChannel* QLCInputProfile::channel(quint32 channel) const
 {
-    if (m_channels.contains(channel) == true)
-        return m_channels[channel];
-    else
-        return NULL;
+    return m_channels.value(channel, NULL);
 }
 
 quint32 QLCInputProfile::channelNumber(const QLCInputChannel* channel) const
@@ -529,10 +527,7 @@ bool QLCInputProfile::loadXML(QXmlStreamReader& doc)
             }
             else if (doc.name() == KXMLQLCInputProfileMidiSendNoteOff)
             {
-                if (doc.readElementText() == KXMLQLCFalse)
-                    setMidiSendNoteOff(false);
-                else
-                    setMidiSendNoteOff(true);
+                setMidiSendNoteOff(doc.readElementText() != KXMLQLCFalse);
             }
             else if (doc.name() == KXMLQLCInputChannel)
             {
@@ -643,7 +638,9 @@ bool QLCInputProfile::saveXML(const QString& fileName)
     /* End the document and close all the open elements */
     doc.writeEndDocument();
     file.close();
-
+#ifdef Q_OS_UNIX
+    sync();
+#endif
     return true;
 }
 
