@@ -21,12 +21,12 @@
 #ifndef RGBMATRIX_H
 #define RGBMATRIX_H
 
+#include <QElapsedTimer>
 #include <QVector>
 #include <QColor>
 #include <QList>
 #include <QSize>
 #include <QPair>
-#include <QHash>
 #include <QMap>
 #include <QMutex>
 
@@ -37,7 +37,6 @@
 #endif
 #include "function.h"
 
-class QElapsedTimer;
 class FixtureGroup;
 class GenericFader;
 class FadeChannel;
@@ -218,7 +217,7 @@ public:
 
 private:
     /** A map of the custom properties for this matrix */
-    QHash<QString, QString>m_properties;
+    QMap<QString, QString>m_properties;
 
     /************************************************************************
      * Load & Save
@@ -265,7 +264,7 @@ public:
 
 private:
     /** Reference to a timer counting the time in ms between steps */
-    QElapsedTimer *m_roundTime;
+    QElapsedTimer m_roundTime;
 
     /** The number of steps returned by the currently loaded algorithm */
     int m_stepsCount;
