@@ -24,6 +24,11 @@
 #include <QDebug>
 #include <QFile>
 
+// cppcheck-suppress missingIncludeSystem
+#include <QCoreApplication>
+// cppcheck-suppress missingIncludeSystem
+#include <QSemaphore>
+
 #include "rgbscriptv4.h"
 
 #include "rgbscriptscache.h"
@@ -34,10 +39,25 @@
  * Initialization
  ****************************************************************************/
 
+JSThread* RGBScript::s_jsThread = NULL;
+
+class JSThread: public QThread
+{
+public:
+    QJSEngine *engine;
+    QSemaphore ready;
+    void run()
+    {
+        engine = new QJSEngine();
+        ready.release(1);
+        exec();
+        delete engine;
+    }
+};
+
+
 RGBScript::RGBScript(Doc *doc)
     : RGBAlgorithm(doc)
-    , m_engine(NULL)
-    , m_engineMutex(NULL)
     , m_apiVersion(0)
 {
 }
@@ -46,8 +66,6 @@ RGBScript::RGBScript(const RGBScript& s)
     : RGBAlgorithm(s.doc())
     , m_fileName(s.m_fileName)
     , m_contents(s.m_contents)
-    , m_engine(NULL)
-    , m_engineMutex(NULL)
     , m_apiVersion(0)
 {
     evaluate();
@@ -59,11 +77,6 @@ RGBScript::RGBScript(const RGBScript& s)
 
 RGBScript::~RGBScript()
 {
-    if (m_engine != NULL)
-    {
-        m_engine->collectGarbage();
-        delete m_engine;
-    }
 }
 
 RGBScript &RGBScript::operator=(const RGBScript &s)
@@ -85,10 +98,7 @@ RGBScript &RGBScript::operator=(const RGBScript &s)
 
 bool RGBScript::operator==(const RGBScript& s) const
 {
-    if (this->fileName().isEmpty() == false && this->fileName() == s.fileName())
-        return true;
-    else
-        return false;
+    return this->fileName().isEmpty() == false && this->fileName() == s.fileName();
 }
 
 RGBAlgorithm* RGBScript::clone() const
@@ -106,14 +116,14 @@ bool RGBScript::load(const QString& fileName)
     // Create the script engine when it's first needed
     initEngine();
 
-    QMutexLocker engineLocker(m_engineMutex);
-
-    m_contents.clear();
-    m_script = QJSValue();
-    m_rgbMap = QJSValue();
-    m_rgbMapStepCount = QJSValue();
-    m_rgbMapSetColors = QJSValue();
-    m_apiVersion = 0;
+    {
+        m_contents.clear();
+        m_script = QJSValue();
+        m_rgbMap = QJSValue();
+        m_rgbMapStepCount = QJSValue();
+        m_rgbMapSetColors = QJSValue();
+        m_apiVersion = 0;
+    }
 
     m_fileName = fileName;
     QFile file(m_fileName);
@@ -137,23 +147,35 @@ QString RGBScript::fileName() const
 
 void RGBScript::initEngine()
 {
-    if (m_engineMutex == NULL)
+    if (s_jsThread == NULL)
     {
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-        m_engineMutex = new QMutex(QMutex::Recursive);
-#else
-        m_engineMutex = new QRecursiveMutex();
-#endif
-        m_engine = new QJSEngine();
-        m_threadId = QThread::currentThreadId();
-        qDebug() << "ENGINE CREATED" << QThread::currentThreadId();
+        s_jsThread = new JSThread();
+        s_jsThread->start();
+        // cppcheck-suppress unknownMacro
+        qAddPostRoutine(RGBScript::cleanupEngine);
+        s_jsThread->ready.acquire(1);
     }
-    Q_ASSERT(m_engineMutex != NULL);
-    Q_ASSERT(m_engine != NULL);
+    Q_ASSERT(s_jsThread->engine != NULL);
 }
 
+void RGBScript::cleanupEngine()
+{
+    s_jsThread->exit();
+    s_jsThread->wait();
+    delete s_jsThread;
+    s_jsThread = NULL;
+}
+
+
 bool RGBScript::evaluate()
 {
+    if (QThread::currentThread() != s_jsThread)
+    {
+        bool retVal;
+        QMetaObject::invokeMethod(s_jsThread->engine, [this]{ return evaluate();}, Qt::BlockingQueuedConnection, &retVal);
+        return retVal;
+    }
+
     m_rgbMap = QJSValue();
     m_rgbMapStepCount = QJSValue();
     m_rgbMapSetColors = QJSValue();
@@ -165,24 +187,23 @@ bool RGBScript::evaluate()
         return false;
     }
 
-    if (m_engine == NULL)
-        initEngine();
+    initEngine();
 
-    m_script = m_engine->evaluate(m_contents, m_fileName);
+    m_script = s_jsThread->engine->evaluate(m_contents, m_fileName);
     if (m_script.isError())
     {
         displayError(m_script, m_fileName);
         return false;
     }
 
-    m_rgbMap = m_script.property("rgbMap");
+    m_rgbMap = m_script.property(QStringLiteral("rgbMap"));
     if (m_rgbMap.isCallable() == false)
     {
         qWarning() << m_fileName << "is missing the rgbMap() function!";
         return false;
     }
 
-    m_rgbMapStepCount = m_script.property("rgbMapStepCount");
+    m_rgbMapStepCount = m_script.property(QStringLiteral("rgbMapStepCount"));
     if (m_rgbMapStepCount.isCallable() == false)
     {
         qWarning() << m_fileName << "is missing the rgbMapStepCount() function!";
@@ -194,7 +215,7 @@ bool RGBScript::evaluate()
     {
         if (m_apiVersion >= 3)
         {
-            m_rgbMapSetColors = m_script.property("rgbMapSetColors");
+            m_rgbMapSetColors = m_script.property(QStringLiteral("rgbMapSetColors"));
             if (m_rgbMapSetColors.isCallable() == false)
             {
                 qWarning() << m_fileName << "is missing the rgbMapSetColors() function!";
@@ -230,7 +251,12 @@ void RGBScript::displayError(QJSValue e, const QString& fileName)
 
 int RGBScript::rgbMapStepCount(const QSize& size)
 {
-    QMutexLocker engineLocker(m_engineMutex);
+    if (QThread::currentThread() != s_jsThread)
+    {
+        int retVal;
+        QMetaObject::invokeMethod(s_jsThread->engine, [this, size]{ return rgbMapStepCount(size);}, Qt::BlockingQueuedConnection, &retVal);
+        return retVal;
+    }
 
     if (m_rgbMapStepCount.isCallable() == false)
         return -1;
@@ -250,9 +276,13 @@ int RGBScript::rgbMapStepCount(const QSize& size)
     }
 }
 
-void RGBScript::rgbMapSetColors(QVector<uint> &colors)
+void RGBScript::rgbMapSetColors(const QVector<uint> &colors)
 {
-    QMutexLocker engineLocker(m_engineMutex);
+    if (QThread::currentThread() != s_jsThread)
+    {
+        QMetaObject::invokeMethod(s_jsThread->engine, [this, colors]{ return rgbMapSetColors(colors);}, Qt::QueuedConnection);
+        return;
+    }
 
     if (m_apiVersion <= 2)
         return;
@@ -265,7 +295,8 @@ void RGBScript::rgbMapSetColors(QVector<uint> &colors)
 
     int accColors = acceptColors();
     int rawColorCount = colors.count();
-    QJSValue jsRawColors = m_engine->newArray(accColors);
+
+    QJSValue jsRawColors = s_jsThread->engine->newArray(accColors);
     for (int i = 0; i < rawColorCount && i < accColors; i++)
         jsRawColors.setProperty(i, QJSValue(colors.at(i)));
 
@@ -279,7 +310,13 @@ void RGBScript::rgbMapSetColors(QVector<uint> &colors)
 
 QVector<uint> RGBScript::rgbMapGetColors()
 {
-    QMutexLocker engineLocker(m_engineMutex);
+    if (QThread::currentThread() != s_jsThread)
+    {
+        QVector<uint> retVal;
+        QMetaObject::invokeMethod(s_jsThread->engine, [this]{ return rgbMapGetColors();}, Qt::BlockingQueuedConnection, &retVal);
+        return retVal;
+    }
+
     QVector<uint> colArray;
 
     if (m_rgbMap.isUndefined() == true)
@@ -298,7 +335,11 @@ QVector<uint> RGBScript::rgbMapGetColors()
 
 void RGBScript::rgbMap(const QSize& size, uint rgb, int step, RGBMap &map)
 {
-    QMutexLocker engineLocker(m_engineMutex);
+    if (QThread::currentThread() != s_jsThread)
+    {
+        QMetaObject::invokeMethod(s_jsThread->engine, [this, size, rgb, step, &map]{ rgbMap(size, rgb, step, map);}, Qt::BlockingQueuedConnection);
+        return;
+    }
 
     if (m_rgbMap.isUndefined() == true)
         return;
@@ -336,18 +377,28 @@ void RGBScript::rgbMap(const QSize& size, uint rgb, int step, RGBMap &map)
 
 QString RGBScript::name() const
 {
-    QMutexLocker engineLocker(m_engineMutex);
+    if (QThread::currentThread() != s_jsThread)
+    {
+        QString retVal;
+        QMetaObject::invokeMethod(s_jsThread->engine, [this]{ return name();}, Qt::BlockingQueuedConnection, &retVal);
+        return retVal;
+    }
 
-    QJSValue name = m_script.property("name");
+    QJSValue name = m_script.property(QStringLiteral("name"));
     QString ret = name.isUndefined() ? QString() : name.toString();
     return ret;
 }
 
 QString RGBScript::author() const
 {
-    QMutexLocker engineLocker(m_engineMutex);
+    if (QThread::currentThread() != s_jsThread)
+    {
+        QString retVal;
+        QMetaObject::invokeMethod(s_jsThread->engine, [this]{ return author();}, Qt::BlockingQueuedConnection, &retVal);
+        return retVal;
+    }
 
-    QJSValue author = m_script.property("author");
+    QJSValue author = m_script.property(QStringLiteral("author"));
     QString ret = author.isUndefined() ? QString() : author.toString();
     return ret;
 }
@@ -364,9 +415,14 @@ RGBAlgorithm::Type RGBScript::type() const
 
 int RGBScript::acceptColors() const
 {
-    QMutexLocker engineLocker(m_engineMutex);
+    if (QThread::currentThread() != s_jsThread)
+    {
+        int retVal;
+        QMetaObject::invokeMethod(s_jsThread->engine, [this]{ return acceptColors();}, Qt::BlockingQueuedConnection, &retVal);
+        return retVal;
+    }
 
-    QJSValue accColors = m_script.property("acceptColors");
+    QJSValue accColors = m_script.property(QStringLiteral("acceptColors"));
     if (!accColors.isUndefined())
         return accColors.toInt();
     // if no property is provided, let's assume the script
@@ -410,7 +466,12 @@ QList<RGBScriptProperty> RGBScript::properties()
 
 QHash<QString, QString> RGBScript::propertiesAsStrings()
 {
-    QMutexLocker engineLocker(m_engineMutex);
+    if (QThread::currentThread() != s_jsThread)
+    {
+        QHash<QString, QString> retVal;
+        QMetaObject::invokeMethod(s_jsThread->engine, [this]{ return propertiesAsStrings();}, Qt::BlockingQueuedConnection, &retVal);
+        return retVal;
+    }
 
     QHash<QString, QString> properties;
     foreach (RGBScriptProperty cap, m_properties)
@@ -431,7 +492,12 @@ QHash<QString, QString> RGBScript::propertiesAsStrings()
 
 bool RGBScript::setProperty(QString propertyName, QString value)
 {
-    QMutexLocker engineLocker(m_engineMutex);
+    if (QThread::currentThread() != s_jsThread)
+    {
+        bool retVal;
+        QMetaObject::invokeMethod(s_jsThread->engine, [this, propertyName, value]{ return setProperty(propertyName, value);}, Qt::BlockingQueuedConnection, &retVal);
+        return retVal;
+    }
 
     foreach (RGBScriptProperty cap, m_properties)
     {
@@ -462,7 +528,12 @@ bool RGBScript::setProperty(QString propertyName, QString value)
 
 QString RGBScript::property(QString propertyName) const
 {
-    QMutexLocker engineLocker(m_engineMutex);
+    if (QThread::currentThread() != s_jsThread)
+    {
+        QString retVal;
+        QMetaObject::invokeMethod(s_jsThread->engine, [this, propertyName]{ return property(propertyName);}, Qt::BlockingQueuedConnection, &retVal);
+        return retVal;
+    }
 
     foreach (RGBScriptProperty cap, m_properties)
     {
@@ -496,9 +567,7 @@ QString RGBScript::property(QString propertyName) const
 
 bool RGBScript::loadProperties()
 {
-    QMutexLocker engineLocker(m_engineMutex);
-
-    QJSValue svCaps = m_script.property("properties");
+    QJSValue svCaps = m_script.property(QStringLiteral("properties"));
     if (svCaps.isArray() == false)
     {
         qWarning() << m_fileName << "properties is not an array!";
@@ -518,10 +587,10 @@ bool RGBScript::loadProperties()
     {
         RGBScriptProperty newCap;
 
-        QStringList propsList = cap.split("|");
+        QStringList propsList = cap.split('|');
         foreach (QString prop, propsList)
         {
-            QStringList keyValue = prop.split(":");
+            QStringList keyValue = prop.split(':');
             if (keyValue.length() < 2)
             {
                 qWarning() << prop << ": malformed property. Please fix it.";
@@ -529,22 +598,22 @@ bool RGBScript::loadProperties()
             }
             QString key = keyValue.at(0).simplified();
             QString value = keyValue.at(1);
-            if (key == "name")
+            if (key == QStringLiteral("name"))
             {
                 newCap.m_name = value;
             }
-            else if (key == "type")
+            else if (key == QStringLiteral("type"))
             {
                 if (value == "list") newCap.m_type = RGBScriptProperty::List;
                 else if (value == "float") newCap.m_type = RGBScriptProperty::Float;
                 else if (value == "range") newCap.m_type = RGBScriptProperty::Range;
                 else if (value == "string") newCap.m_type = RGBScriptProperty::String;
             }
-            else if (key == "display")
+            else if (key == QStringLiteral("display"))
             {
                 newCap.m_displayName = value.simplified();
             }
-            else if (key == "values")
+            else if (key == QStringLiteral("values"))
             {
                 QStringList values = value.split(",");
                 switch(newCap.m_type)
@@ -570,11 +639,11 @@ bool RGBScript::loadProperties()
                     break;
                 }
             }
-            else if (key == "write")
+            else if (key == QStringLiteral("write"))
             {
                 newCap.m_writeMethod = value.simplified();
             }
-            else if (key == "read")
+            else if (key == QStringLiteral("read"))
             {
                 newCap.m_readMethod = value.simplified();
             }
