@@ -216,25 +216,20 @@ QSharedPointer<GenericFader> Universe::requestFader(Universe::FaderPriority prio
 
     {
         QMutexLocker fadersLocker(&m_fadersMutex);
-        if (m_faders.isEmpty())
-        {
-            m_faders.append(fader);
-        }
-        else
         {
             for (int i = m_faders.count() - 1; i >= 0; i--)
             {
-                QSharedPointer<GenericFader> f = m_faders.at(i);
+                const QSharedPointer<GenericFader>& f = m_faders.at(i);
                 if (!f.isNull() && f->priority() <= fader->priority())
                 {
                     insertPos = i + 1;
                     break;
                 }
             }
-
-            m_faders.insert(insertPos, fader);
         }
 
+        m_faders.insert(insertPos, fader);
+
         qDebug() << "[Universe]" << id() << ": Generic fader with priority" << fader->priority()
                  << "registered at pos" << insertPos << ", count" << m_faders.count();
     }
@@ -255,12 +250,12 @@ void Universe::dismissFader(QSharedPointer<GenericFader> fader)
 void Universe::requestFaderPriority(QSharedPointer<GenericFader> fader, Universe::FaderPriority priority)
 {
     QMutexLocker fadersLocker(&m_fadersMutex);
-    if (m_faders.contains(fader) == false)
-        return;
-
     int pos = m_faders.indexOf(fader);
     int newPos = 0;
 
+    if (pos == -1)
+        return;
+
     for (int i = m_faders.count() - 1; i >= 0; i--)
     {
         QSharedPointer<GenericFader> f = m_faders.at(i);
