@@ -47,20 +47,20 @@ class Doc;
 
 #define UNIVERSE_SIZE 512
 
-#define KXMLQLCUniverse             QString("Universe")
-#define KXMLQLCUniverseName         QString("Name")
-#define KXMLQLCUniverseID           QString("ID")
-#define KXMLQLCUniversePassthrough  QString("Passthrough")
+#define KXMLQLCUniverse             QStringLiteral("Universe")
+#define KXMLQLCUniverseName         QStringLiteral("Name")
+#define KXMLQLCUniverseID           QStringLiteral("ID")
+#define KXMLQLCUniversePassthrough  QStringLiteral("Passthrough")
 
-#define KXMLQLCUniverseInputPatch    QString("Input")
-#define KXMLQLCUniverseOutputPatch   QString("Output")
-#define KXMLQLCUniverseFeedbackPatch QString("Feedback")
+#define KXMLQLCUniverseInputPatch    QStringLiteral("Input")
+#define KXMLQLCUniverseOutputPatch   QStringLiteral("Output")
+#define KXMLQLCUniverseFeedbackPatch QStringLiteral("Feedback")
 
-#define KXMLQLCUniversePlugin           QString("Plugin")
-#define KXMLQLCUniverseLine             QString("Line")
-#define KXMLQLCUniverseLineUID          QString("UID")
-#define KXMLQLCUniverseProfileName      QString("Profile")
-#define KXMLQLCUniversePluginParameters QString("PluginParameters")
+#define KXMLQLCUniversePlugin           QStringLiteral("Plugin")
+#define KXMLQLCUniverseLine             QStringLiteral("Line")
+#define KXMLQLCUniverseLineUID          QStringLiteral("UID")
+#define KXMLQLCUniverseProfileName      QStringLiteral("Profile")
+#define KXMLQLCUniversePluginParameters QStringLiteral("PluginParameters")
 
 /** Universe class contains input/output data for one DMX universe
  */
@@ -525,6 +525,7 @@ public:
      *
      * @param address The DMX start address to write to
      * @param value The value to write
+     * @param forceLTP Force to skip the HTP check
      *
      * @return true if successful, otherwise false
      */
@@ -536,6 +537,7 @@ public:
      * @param address The DMX start address to write to
      * @param value the DMX value(s) to set
      * @param channelCount number of channels that value represents
+     *
      * @return always true
      */
     bool writeMultiple(int address, quint32 value, int channelCount);
