@@ -86,9 +86,10 @@ QString IOPluginStub::outputInfo(quint32 output)
     return QString("This is a plugin stub for testing.");
 }
 
-void IOPluginStub::writeUniverse(quint32 universe, quint32 output, const QByteArray &data)
+void IOPluginStub::writeUniverse(quint32 universe, quint32 output, const QByteArray &data, bool dataChanged)
 {
     Q_UNUSED(universe)
+    Q_UNUSED(dataChanged)
 
     m_universe = m_universe.replace(output * 512, data.size(), data);
 }
