@@ -33,9 +33,11 @@ private slots:
 
     void duplicates();
     void add();
+    void reload();
     void fixtureDef();
 	void load();
     void defDirectories();
+    void storeDef();
 
 private:
     QLCFixtureDefCache cache;
