@@ -264,73 +264,73 @@ void QLCFixtureMode_Test::heads()
     head.addChannel(20);
     mode->insertHead(-1, head);
     QCOMPARE(mode->heads().size(), 1);
-    QVERIFY(mode->m_heads[0].m_channels.contains(0) == true);
-    QVERIFY(mode->m_heads[0].m_channels.contains(10) == true);
-    QVERIFY(mode->m_heads[0].m_channels.contains(20) == true);
+    QVERIFY(mode->m_heads[0].m_channels.contains(quint32(0)) == true);
+    QVERIFY(mode->m_heads[0].m_channels.contains(quint32(10)) == true);
+    QVERIFY(mode->m_heads[0].m_channels.contains(quint32(20)) == true);
 
     QLCFixtureHead head2;
     head2.addChannel(1);
     head2.addChannel(2);
     mode->insertHead(10, head2);
     QCOMPARE(mode->heads().size(), 2);
-    QVERIFY(mode->m_heads[0].m_channels.contains(0) == true);
-    QVERIFY(mode->m_heads[0].m_channels.contains(10) == true);
-    QVERIFY(mode->m_heads[0].m_channels.contains(20) == true);
-    QVERIFY(mode->m_heads[1].m_channels.contains(0) == false);
-    QVERIFY(mode->m_heads[1].m_channels.contains(1) == true);
-    QVERIFY(mode->m_heads[1].m_channels.contains(2) == true);
+    QVERIFY(mode->m_heads[0].m_channels.contains(quint32(0)) == true);
+    QVERIFY(mode->m_heads[0].m_channels.contains(quint32(10)) == true);
+    QVERIFY(mode->m_heads[0].m_channels.contains(quint32(20)) == true);
+    QVERIFY(mode->m_heads[1].m_channels.contains(quint32(0)) == false);
+    QVERIFY(mode->m_heads[1].m_channels.contains(quint32(1)) == true);
+    QVERIFY(mode->m_heads[1].m_channels.contains(quint32(2)) == true);
 
     QLCFixtureHead head3;
     head3.addChannel(3);
     head3.addChannel(4);
     mode->insertHead(1, head3);
     QCOMPARE(mode->heads().size(), 3);
-    QVERIFY(mode->m_heads[0].m_channels.contains(0) == true);
-    QVERIFY(mode->m_heads[0].m_channels.contains(10) == true);
-    QVERIFY(mode->m_heads[0].m_channels.contains(20) == true);
-    QVERIFY(mode->m_heads[1].m_channels.contains(3) == true);
-    QVERIFY(mode->m_heads[1].m_channels.contains(4) == true);
-    QVERIFY(mode->m_heads[2].m_channels.contains(1) == true);
-    QVERIFY(mode->m_heads[2].m_channels.contains(2) == true);
+    QVERIFY(mode->m_heads[0].m_channels.contains(quint32(0)) == true);
+    QVERIFY(mode->m_heads[0].m_channels.contains(quint32(10)) == true);
+    QVERIFY(mode->m_heads[0].m_channels.contains(quint32(20)) == true);
+    QVERIFY(mode->m_heads[1].m_channels.contains(quint32(3)) == true);
+    QVERIFY(mode->m_heads[1].m_channels.contains(quint32(4)) == true);
+    QVERIFY(mode->m_heads[2].m_channels.contains(quint32(1)) == true);
+    QVERIFY(mode->m_heads[2].m_channels.contains(quint32(2)) == true);
 
     QLCFixtureHead head4;
     head4.addChannel(15);
     head4.addChannel(16);
     mode->replaceHead(4, head4);
     QCOMPARE(mode->heads().size(), 3);
-    QVERIFY(mode->m_heads[0].m_channels.contains(0) == true);
-    QVERIFY(mode->m_heads[0].m_channels.contains(10) == true);
-    QVERIFY(mode->m_heads[0].m_channels.contains(20) == true);
-    QVERIFY(mode->m_heads[1].m_channels.contains(3) == true);
-    QVERIFY(mode->m_heads[1].m_channels.contains(4) == true);
-    QVERIFY(mode->m_heads[2].m_channels.contains(1) == true);
-    QVERIFY(mode->m_heads[2].m_channels.contains(2) == true);
+    QVERIFY(mode->m_heads[0].m_channels.contains(quint32(0)) == true);
+    QVERIFY(mode->m_heads[0].m_channels.contains(quint32(10)) == true);
+    QVERIFY(mode->m_heads[0].m_channels.contains(quint32(20)) == true);
+    QVERIFY(mode->m_heads[1].m_channels.contains(quint32(3)) == true);
+    QVERIFY(mode->m_heads[1].m_channels.contains(quint32(4)) == true);
+    QVERIFY(mode->m_heads[2].m_channels.contains(quint32(1)) == true);
+    QVERIFY(mode->m_heads[2].m_channels.contains(quint32(2)) == true);
 
     mode->replaceHead(2, head4);
     QCOMPARE(mode->heads().size(), 3);
-    QVERIFY(mode->m_heads[0].m_channels.contains(0) == true);
-    QVERIFY(mode->m_heads[0].m_channels.contains(10) == true);
-    QVERIFY(mode->m_heads[0].m_channels.contains(20) == true);
-    QVERIFY(mode->m_heads[1].m_channels.contains(3) == true);
-    QVERIFY(mode->m_heads[1].m_channels.contains(4) == true);
-    QVERIFY(mode->m_heads[2].m_channels.contains(15) == true);
-    QVERIFY(mode->m_heads[2].m_channels.contains(16) == true);
+    QVERIFY(mode->m_heads[0].m_channels.contains(quint32(0)) == true);
+    QVERIFY(mode->m_heads[0].m_channels.contains(quint32(10)) == true);
+    QVERIFY(mode->m_heads[0].m_channels.contains(quint32(20)) == true);
+    QVERIFY(mode->m_heads[1].m_channels.contains(quint32(3)) == true);
+    QVERIFY(mode->m_heads[1].m_channels.contains(quint32(4)) == true);
+    QVERIFY(mode->m_heads[2].m_channels.contains(quint32(15)) == true);
+    QVERIFY(mode->m_heads[2].m_channels.contains(quint32(16)) == true);
 
     mode->removeHead(15);
     QCOMPARE(mode->heads().size(), 3);
 
     mode->removeHead(1);
     QCOMPARE(mode->heads().size(), 2);
-    QVERIFY(mode->m_heads[0].m_channels.contains(0) == true);
-    QVERIFY(mode->m_heads[0].m_channels.contains(10) == true);
-    QVERIFY(mode->m_heads[0].m_channels.contains(20) == true);
-    QVERIFY(mode->m_heads[1].m_channels.contains(15) == true);
-    QVERIFY(mode->m_heads[1].m_channels.contains(16) == true);
+    QVERIFY(mode->m_heads[0].m_channels.contains(quint32(0)) == true);
+    QVERIFY(mode->m_heads[0].m_channels.contains(quint32(10)) == true);
+    QVERIFY(mode->m_heads[0].m_channels.contains(quint32(20)) == true);
+    QVERIFY(mode->m_heads[1].m_channels.contains(quint32(15)) == true);
+    QVERIFY(mode->m_heads[1].m_channels.contains(quint32(16)) == true);
 
     mode->removeHead(0);
     QCOMPARE(mode->heads().size(), 1);
-    QVERIFY(mode->m_heads[0].m_channels.contains(15) == true);
-    QVERIFY(mode->m_heads[0].m_channels.contains(16) == true);
+    QVERIFY(mode->m_heads[0].m_channels.contains(quint32(15)) == true);
+    QVERIFY(mode->m_heads[0].m_channels.contains(quint32(16)) == true);
 
     mode->removeHead(0);
     QCOMPARE(mode->heads().size(), 0);
@@ -365,9 +365,9 @@ void QLCFixtureMode_Test::copy()
     QVERIFY(copy->channel(2) == m_ch3);
     QVERIFY(copy->channel(3) == m_ch4);
     QCOMPARE(copy->heads().size(), 1);
-    QVERIFY(copy->heads().at(0).channels().contains(0) == true);
-    QVERIFY(copy->heads().at(0).channels().contains(1) == true);
-    QVERIFY(copy->heads().at(0).channels().contains(2) == true);
+    QVERIFY(copy->heads().at(0).channels().contains(quint32(0)) == true);
+    QVERIFY(copy->heads().at(0).channels().contains(quint32(1)) == true);
+    QVERIFY(copy->heads().at(0).channels().contains(quint32(2)) == true);
     delete copy;
     copy = NULL;
 
