@@ -20,16 +20,16 @@
 #ifndef UTIL_H
 #define UTIL_H
 
-#include <QRegExpValidator>
-#include <QRegExp>
+#include <QRegularExpression>
+#include <QRegularExpressionValidator>
 
 /** @addtogroup fixtureeditor Fixture Editor
  * @{
  */
 
-//! Prevent people from using ALL CAPS. It's fucking annoying.
-#define REGEXP_CAPS "(([^A-Z]*[A-Z]{,5}[^A-Z]+)*)"
-#define CAPS_VALIDATOR(parent) new QRegExpValidator(QRegExp(REGEXP_CAPS), parent)
+//! Prevent people from using ALL CAPS. It's fucking annoying. Allow max. 5 consecutive CAPS in a row
+#define REGEXP_CAPS "[^A-Z]*[A-Z]{0,5}([^A-Z]+[A-Z]{0,5})*"
+#define CAPS_VALIDATOR(parent) new QRegularExpressionValidator(QRegularExpression(REGEXP_CAPS), parent)
 
 /** @} */
 
