@@ -36,9 +36,6 @@ public:
 
     static QList<DMXInterface *> interfaces(QList<DMXInterface *> discoveredList);
 
-    /** @reimpl */
-    bool readLabel(uchar label, int &intParam, QString &strParam);
-
     /************************************************************************
      * DMX/Serial Interface Methods
      ************************************************************************/
@@ -89,7 +86,7 @@ public:
     bool write(const QByteArray& data);
 
     /** @reimpl */
-    QByteArray read(int size, uchar* buffer = NULL);
+    QByteArray read(int size);
 
     /** @reimpl */
     uchar readByte(bool* ok = NULL);
