@@ -65,7 +65,7 @@ public:
     QString outputInfo(quint32 output);
 
     /** @reimp */
-    void writeUniverse(quint32 universe, quint32 output, const QByteArray& data);
+    void writeUniverse(quint32 universe, quint32 output, const QByteArray& data, bool dataChanged);
 
     /*************************************************************************
      * Inputs - If the plugin doesn't provide input
@@ -85,7 +85,7 @@ public:
     QString inputInfo(quint32 input);
 
     /** @reimp */
-    void sendFeedBack(quint32 universe, quint32 output, quint32 channel, uchar value, const QString& key);
+    void sendFeedBack(quint32 universe, quint32 output, quint32 channel, uchar value, const QVariant &params);
 
 protected:
     /** Place here the variables used by this plugin */
