@@ -21,7 +21,7 @@
     <message>
         <location filename="configurehid.ui" line="62"/>
         <source>Merger Mode</source>
-        <translation type="unfinished"></translation>
+        <translation>Modo Fusión</translation>
     </message>
     <message>
         <location filename="configurehid.ui" line="70"/>
@@ -45,12 +45,12 @@
 <context>
     <name>HIDJsDevice</name>
     <message>
-        <location filename="hidjsdevice.cpp" line="88"/>
+        <location filename="hidjsdevice.cpp" line="116"/>
         <source>Axes: %1</source>
         <translation>Ejes: %1</translation>
     </message>
     <message>
-        <location filename="hidjsdevice.cpp" line="90"/>
+        <location filename="hidjsdevice.cpp" line="118"/>
         <source>Buttons: %1</source>
         <translation>Botones: %1</translation>
     </message>
