@@ -3,12 +3,6 @@
 <TS version="2.1" language="ca_ES">
 <context>
     <name>Loopback</name>
-    <message>
-        <location filename="loopback.cpp" line="91"/>
-        <location filename="loopback.cpp" line="117"/>
-        <source>Loopback</source>
-        <translation>Loopback</translation>
-    </message>
     <message>
         <location filename="loopback.cpp" line="133"/>
         <source>This plugin provides DMX loopback. Data written to each output is forwarded to the respective input.</source>
