@@ -27,6 +27,8 @@
 
 #include "qlcioplugin.h"
 
+#define SETTINGS_OUTPUT_FREQUENCY "SPIPlugin/frequency"
+
 typedef struct
 {
     /** number of channels used in a universe */
@@ -86,7 +88,7 @@ public:
     QString outputInfo(quint32 output);
 
     /** @reimp */
-    void writeUniverse(quint32 universe, quint32 output, const QByteArray& data);
+    void writeUniverse(quint32 universe, quint32 output, const QByteArray& data, bool dataChanged);
 
 protected:
     /** File handle for /dev/spidev0.0 */
