@@ -4,12 +4,12 @@
 <context>
     <name>UDMX</name>
     <message>
-        <location filename="udmx.cpp" line="101"/>
+        <location filename="udmx.cpp" line="100"/>
         <source>This plugin provides DMX output support for Anyma uDMX devices.</source>
         <translation type="unfinished">Tämä liitännäinen tuottaa DMX-ulostulotuen Anyma uDMX-laitteille.</translation>
     </message>
     <message>
-        <location filename="udmx.cpp" line="195"/>
+        <location filename="udmx.cpp" line="199"/>
         <source>Do you wish to re-scan your hardware?</source>
         <translation type="unfinished">Etsitäänkö lisää laitteita?</translation>
     </message>
@@ -17,49 +17,49 @@
 <context>
     <name>UDMXDevice</name>
     <message>
-        <location filename="udmxdevice.cpp" line="130"/>
+        <location filename="udmxdevice.cpp" line="122"/>
         <source>Unknown</source>
         <translation>Tuntematon</translation>
     </message>
     <message>
-        <location filename="udmxdevice.cpp" line="151"/>
+        <location filename="udmxdevice.cpp" line="142"/>
+        <source>Device name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="udmxdevice.cpp" line="144"/>
         <source>DMX Channels</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="udmxdevice.cpp" line="153"/>
+        <location filename="udmxdevice.cpp" line="146"/>
         <source>DMX Frame Frequency</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="udmxdevice.cpp" line="156"/>
+        <location filename="udmxdevice.cpp" line="149"/>
         <source>Bad</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="udmxdevice.cpp" line="158"/>
+        <location filename="udmxdevice.cpp" line="151"/>
         <source>Good</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="udmxdevice.cpp" line="160"/>
+        <location filename="udmxdevice.cpp" line="153"/>
         <source>Patch this device to a universe to find out.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="udmxdevice.cpp" line="161"/>
+        <location filename="udmxdevice.cpp" line="154"/>
         <source>System Timer Accuracy</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="udmxdevice.cpp" line="166"/>
-        <source>Unknown device</source>
-        <translation>Tuntematon laite</translation>
-    </message>
-    <message>
-        <location filename="udmxdevice.cpp" line="168"/>
-        <source>Cannot connect to USB device.</source>
-        <translation>USB-laitteeseen ei saada yhteyttä.</translation>
+        <location filename="udmxdevice.cpp" line="159"/>
+        <source>Device not in use</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
