@@ -207,8 +207,9 @@ const struct libusb_device* UDMXDevice::device() const
 
 void UDMXDevice::outputDMX(const QByteArray& universe)
 {
-    m_universe.replace(0, qMin(universe.size(), m_universe.size()), universe.constData(),
-                          qMin(universe.size(), m_universe.size()));
+    int offset = 0;
+    m_universe.replace(offset, qMin(universe.size(), m_universe.size()), universe.constData(),
+                       qMin(universe.size(), m_universe.size()));
 }
 
 void UDMXDevice::stop()
