@@ -18,9 +18,7 @@
 */
 
 #include <stdlib.h>
-#if defined(WIN32) || defined(Q_OS_WIN)
-#       include <stdint.h> // int32_t
-#endif
+#include <stdint.h> // int32_t
 
 extern "C"
 {
