@@ -46,7 +46,7 @@ class VideoProvider;
 class FixtureEditor;
 class Tardis;
 
-#define KXMLQLCWorkspace QString("Workspace")
+#define KXMLQLCWorkspace QStringLiteral("Workspace")
 
 class App : public QQuickView
 {
@@ -166,6 +166,8 @@ public:
 
     bool is3DSupported() const;
 
+    Q_INVOKABLE void aboutQt();
+
     Q_INVOKABLE void exit();
 
 public slots:
