@@ -100,6 +100,33 @@ bool ModeEdit::deleteChannel(QLCChannel *channel)
     return res;
 }
 
+QStringList ModeEdit::actsOnChannels()
+{
+    QStringList list;
+    list << "-";
+
+    for (QLCChannel *channel : m_mode->channels())
+        list << channel->name();
+
+    return list;
+}
+
+int ModeEdit::actsOnChannel(int index)
+{
+    quint32 actsOnChannelIndex = m_mode->channelActsOn(index);
+
+    if (actsOnChannelIndex != QLCChannel::invalid())
+        return actsOnChannelIndex + 1;
+    else
+        return 0;
+}
+
+void ModeEdit::setActsOnChannel(int sourceIndex, int destIndex)
+{
+    quint32 actsOnChannel = destIndex == 0 ? QLCChannel::invalid() : destIndex - 1;
+    m_mode->setChannelActsOn(sourceIndex, actsOnChannel);
+}
+
 void ModeEdit::updateChannelList()
 {
     m_channelList->clear();
@@ -113,6 +140,7 @@ void ModeEdit::updateChannelList()
     }
 
     emit channelsChanged();
+    emit actsOnChannelsChanged();
 }
 
 /************************************************************************
