@@ -437,10 +437,18 @@ void FixtureGroupEditor::transformSelection(int transformation)
             trImage = matrix.transformed(transform);
         break;
         case HorizontalFlip:
+#if (QT_VERSION < QT_VERSION_CHECK(6, 9, 0))
             trImage = matrix.mirrored(true, false);
+#else
+            trImage = matrix.flipped(Qt::Horizontal);
+#endif
         break;
         case VerticalFlip:
+#if (QT_VERSION < QT_VERSION_CHECK(6, 9, 0))
             trImage = matrix.mirrored(false, true);
+#else
+            trImage = matrix.flipped(Qt::Vertical);
+#endif
         break;
     }
 
