@@ -88,6 +88,8 @@ public:
     /** Read only property to expose the function tree to the QML UI */
     QVariant functionsList();
 
+    Q_INVOKABLE quint32 nextFunctionId() const;
+
     /** Get a list of Functions that use $fid */
     Q_INVOKABLE QVariantList usageList(quint32 fid);
 
@@ -169,7 +171,7 @@ public:
      *  with the provided $newName.
      *  If $numbering is true, then $startNumber and $digits will compose
      *  a progress number following $newName */
-    Q_INVOKABLE void renameSelectedItems(QString newName, bool numbering, int startNumber, int digits);
+    Q_INVOKABLE bool renameSelectedItems(QString newName, bool numbering, int startNumber, int digits);
 
     /** Returns the number of the currently selected Functions */
     int selectedFunctionCount() const;
@@ -289,6 +291,9 @@ public:
     /** Reset the currently set channel values */
     void resetDumpValues();
 
+    void dumpDmxValues(QList<SceneValue> dumpValues, QList<quint32> selectedFixtures,
+                       quint32 channelMask, QString sceneName, quint32 sceneID, bool nonZeroOnly);
+
     /** Dump DMX values provided by $dumpValues, filtered by the provided $selectedFixtures
      *  and the provided $channelMask.
      *  The new Scene will be named with $name if not empty, otherwise with an autogenerated name */
