@@ -22,24 +22,24 @@
 
 #include "vcwidget.h"
 
-#define KXMLQLCVCButton QString("Button")
+#define KXMLQLCVCButton QStringLiteral("Button")
 
-#define KXMLQLCVCButtonFunction     QString("Function")
-#define KXMLQLCVCButtonFunctionID   QString("ID")
+#define KXMLQLCVCButtonFunction     QStringLiteral("Function")
+#define KXMLQLCVCButtonFunctionID   QStringLiteral("ID")
 
-#define KXMLQLCVCButtonAction           QString("Action")
-#define KXMLQLCVCButtonActionFlash      QString("Flash")
-#define KXMLQLCVCButtonActionToggle     QString("Toggle")
-#define KXMLQLCVCButtonActionBlackout   QString("Blackout")
-#define KXMLQLCVCButtonActionStopAll    QString("StopAll")
+#define KXMLQLCVCButtonAction           QStringLiteral("Action")
+#define KXMLQLCVCButtonActionFlash      QStringLiteral("Flash")
+#define KXMLQLCVCButtonActionToggle     QStringLiteral("Toggle")
+#define KXMLQLCVCButtonActionBlackout   QStringLiteral("Blackout")
+#define KXMLQLCVCButtonActionStopAll    QStringLiteral("StopAll")
 
-#define KXMLQLCVCButtonFlashOverride    QString("Override")
-#define KXMLQLCVCButtonFlashForceLTP    QString("ForceLTP")
+#define KXMLQLCVCButtonFlashOverride    QStringLiteral("Override")
+#define KXMLQLCVCButtonFlashForceLTP    QStringLiteral("ForceLTP")
 
-#define KXMLQLCVCButtonStopAllFadeTime  QString("FadeOut")
+#define KXMLQLCVCButtonStopAllFadeTime  QStringLiteral("FadeOut")
 
-#define KXMLQLCVCButtonIntensity        QString("Intensity")
-#define KXMLQLCVCButtonIntensityAdjust  QString("Adjust")
+#define KXMLQLCVCButtonIntensity        QStringLiteral("Intensity")
+#define KXMLQLCVCButtonIntensityAdjust  QStringLiteral("Adjust")
 
 class FunctionParent;
 
