@@ -1079,11 +1079,11 @@ bool VCCueList::saveXML(QXmlStreamWriter *doc)
         doc->writeTextElement(KXMLQLCVCCueListSlidersMode, faderModeToString(sideFaderMode()));
 
     /* Input controls */
-    saveXMLInputControl(doc, INPUT_NEXT_STEP_ID, KXMLQLCVCCueListNext);
-    saveXMLInputControl(doc, INPUT_PREVIOUS_STEP_ID, KXMLQLCVCCueListPrevious);
-    saveXMLInputControl(doc, INPUT_PLAY_PAUSE_ID, KXMLQLCVCCueListPlayback);
-    saveXMLInputControl(doc, INPUT_STOP_PAUSE_ID, KXMLQLCVCCueListStop);
-    saveXMLInputControl(doc, INPUT_SIDE_FADER_ID, KXMLQLCVCCueListCrossfadeLeft);
+    saveXMLInputControl(doc, INPUT_NEXT_STEP_ID, false, KXMLQLCVCCueListNext);
+    saveXMLInputControl(doc, INPUT_PREVIOUS_STEP_ID, false, KXMLQLCVCCueListPrevious);
+    saveXMLInputControl(doc, INPUT_PLAY_PAUSE_ID, false, KXMLQLCVCCueListPlayback);
+    saveXMLInputControl(doc, INPUT_STOP_PAUSE_ID, false, KXMLQLCVCCueListStop);
+    saveXMLInputControl(doc, INPUT_SIDE_FADER_ID, false, KXMLQLCVCCueListCrossfadeLeft);
 
     /* End the <CueList> tag */
     doc->writeEndElement();
