@@ -579,7 +579,7 @@ void VCSlider::setSearchFilter(QString searchFilter)
 
 void VCSlider::removeActiveFaders()
 {
-    foreach (QSharedPointer<GenericFader> fader, m_fadersMap.values())
+    foreach (QSharedPointer<GenericFader> fader, m_fadersMap)
     {
         if (!fader.isNull())
             fader->requestDelete();
