@@ -22,24 +22,24 @@
 
 #include "vcwidget.h"
 
-#define KXMLQLCVCSpeedDial                  QString("SpeedDial")
-#define KXMLQLCVCSpeedDialAbsoluteValue     QString("AbsoluteValue")
-#define KXMLQLCVCSpeedDialAbsoluteValueMin  QString("Minimum")
-#define KXMLQLCVCSpeedDialAbsoluteValueMax  QString("Maximum")
-#define KXMLQLCVCSpeedDialTap               QString("Tap")
-#define KXMLQLCVCSpeedDialMult              QString("Mult")
-#define KXMLQLCVCSpeedDialDiv               QString("Div")
-#define KXMLQLCVCSpeedDialMultDivReset      QString("MultDivReset")
-#define KXMLQLCVCSpeedDialApply             QString("Apply")
-#define KXMLQLCVCSpeedDialTapKey            QString("Key")
-#define KXMLQLCVCSpeedDialMultKey           QString("MultKey")
-#define KXMLQLCVCSpeedDialDivKey            QString("DivKey")
-#define KXMLQLCVCSpeedDialMultDivResetKey   QString("MultDivResetKey")
-#define KXMLQLCVCSpeedDialApplyKey          QString("ApplyKey")
-#define KXMLQLCVCSpeedDialResetFactorOnDialChange QString("ResetFactorOnDialChange")
-#define KXMLQLCVCSpeedDialVisibilityMask    QString("Visibility")
-#define KXMLQLCVCSpeedDialTime              QString("Time")
-#define KXMLQLCVCSpeedDialFunction          QString("Function")
+#define KXMLQLCVCSpeedDial                  QStringLiteral("SpeedDial")
+#define KXMLQLCVCSpeedDialAbsoluteValue     QStringLiteral("AbsoluteValue")
+#define KXMLQLCVCSpeedDialAbsoluteValueMin  QStringLiteral("Minimum")
+#define KXMLQLCVCSpeedDialAbsoluteValueMax  QStringLiteral("Maximum")
+#define KXMLQLCVCSpeedDialTap               QStringLiteral("Tap")
+#define KXMLQLCVCSpeedDialMult              QStringLiteral("Mult")
+#define KXMLQLCVCSpeedDialDiv               QStringLiteral("Div")
+#define KXMLQLCVCSpeedDialMultDivReset      QStringLiteral("MultDivReset")
+#define KXMLQLCVCSpeedDialApply             QStringLiteral("Apply")
+#define KXMLQLCVCSpeedDialTapKey            QStringLiteral("Key")
+#define KXMLQLCVCSpeedDialMultKey           QStringLiteral("MultKey")
+#define KXMLQLCVCSpeedDialDivKey            QStringLiteral("DivKey")
+#define KXMLQLCVCSpeedDialMultDivResetKey   QStringLiteral("MultDivResetKey")
+#define KXMLQLCVCSpeedDialApplyKey          QStringLiteral("ApplyKey")
+#define KXMLQLCVCSpeedDialResetFactorOnDialChange QStringLiteral("ResetFactorOnDialChange")
+#define KXMLQLCVCSpeedDialVisibilityMask    QStringLiteral("Visibility")
+#define KXMLQLCVCSpeedDialTime              QStringLiteral("Time")
+#define KXMLQLCVCSpeedDialFunction          QStringLiteral("Function")
 
 class VCSpeedDial : public VCWidget
 {
@@ -145,7 +145,7 @@ private:
      * Dial absolute time
      *********************************************************************/
 public:
-    /* Get/Set the time range minumum value */
+    /* Get/Set the time range minimum value */
     uint timeMinimumValue() const;
     void setTimeMinimumValue(uint newTimeMinimumValue);
 
