@@ -1448,17 +1448,17 @@ bool VCWidget::saveXMLInputControl(QXmlStreamWriter *doc, quint8 controlId, bool
         // save feedback extra params
         QVariant extraParams = source->feedbackExtraParams(QLCInputFeedback::LowerValue);
 
-        if (extraParams.isValid() && extraParams.type() == QVariant::Int && extraParams.toInt() != -1)
+        if (extraParams.isValid() && extraParams.userType() == QMetaType::Int && extraParams.toInt() != -1)
             doc->writeAttribute(KXMLQLCVCWidgetInputLowerParams, QString::number(extraParams.toInt()));
 
         extraParams = source->feedbackExtraParams(QLCInputFeedback::UpperValue);
 
-        if (extraParams.isValid() && extraParams.type() == QVariant::Int && extraParams.toInt() != -1)
+        if (extraParams.isValid() && extraParams.userType() == QMetaType::Int && extraParams.toInt() != -1)
             doc->writeAttribute(KXMLQLCVCWidgetInputUpperParams, QString::number(extraParams.toInt()));
 
         extraParams = source->feedbackExtraParams(QLCInputFeedback::MonitorValue);
 
-        if (extraParams.isValid() && extraParams.type() == QVariant::Int && extraParams.toInt() != -1)
+        if (extraParams.isValid() && extraParams.userType() == QMetaType::Int && extraParams.toInt() != -1)
             doc->writeAttribute(KXMLQLCVCWidgetInputMonitorParams, QString::number(extraParams.toInt()));
     }
 
