@@ -545,7 +545,7 @@ void VirtualConsole::setWidgetSelection(quint32 wID, QQuickItem *item, bool enab
 
 void VirtualConsole::resetWidgetSelection()
 {
-    foreach (QQuickItem *widget, m_itemsMap.values())
+    foreach (QQuickItem *widget, m_itemsMap)
         widget->setProperty("isSelected", false);
     m_itemsMap.clear();
 
@@ -556,11 +556,12 @@ void VirtualConsole::resetWidgetSelection()
 QStringList VirtualConsole::selectedWidgetNames()
 {
     QStringList names;
-    if (m_itemsMap.isEmpty() == false)
+
     {
-        foreach (quint32 wID, m_itemsMap.keys())
+        QMap<quint32, QQuickItem*>::iterator it = m_itemsMap.begin();
+        for (; it != m_itemsMap.end(); it++)
         {
-            VCWidget *vcWidget = m_widgetsMap[wID];
+            VCWidget *vcWidget = m_widgetsMap[it.key()];
             if (vcWidget != nullptr)
             {
                 if (vcWidget->caption().isEmpty())
@@ -576,16 +577,17 @@ QStringList VirtualConsole::selectedWidgetNames()
 
 int VirtualConsole::selectedWidgetsCount() const
 {
-    return m_itemsMap.keys().count();
+    return m_itemsMap.count();
 }
 
 QVariantList VirtualConsole::selectedWidgetIDs()
 {
     QVariantList ids;
-    if (m_itemsMap.isEmpty() == false)
+
+    QMap<quint32, QQuickItem*>::iterator it = m_itemsMap.begin();
+    for (; it != m_itemsMap.end(); it++)
     {
-        foreach (quint32 wID, m_itemsMap.keys())
-            ids << wID;
+        ids << it.key();
     }
 
     return ids;
