@@ -146,6 +146,9 @@ AddFixture::AddFixture(QWidget* parent, const Doc* doc, const Fixture* fxi)
     if (var.isValid() == true)
         restoreGeometry(var.toByteArray());
     AppUtil::ensureWidgetIsVisible(this);
+
+    // Set focus on the search bar
+    m_searchEdit->setFocus();
 }
 
 AddFixture::~AddFixture()
@@ -405,7 +408,13 @@ quint32 AddFixture::findAddress(quint32 universe, quint32 numChannels,
             continue;
 
         for (quint32 ch = 0; ch < fxi->channels(); ch++)
-            map[(fxi->universeAddress() & 0x01FF) + ch] = 1;
+        {
+            quint32 addr = (fxi->universeAddress() & 0x01FF) + ch;
+            if (addr > 511)
+                continue;
+
+            map[addr] = 1;
+        }
     }
 
     /* Try to find the next contiguous free address space */
