@@ -20,8 +20,9 @@
 */
 
 #include <QToolButton>
-#include <QtCore>
 #include <QtWidgets>
+#include <unistd.h>
+#include <QtCore>
 
 #if defined(WIN32) || defined(Q_OS_WIN)
   #include <windows.h>
@@ -61,6 +62,20 @@
 extern void qt_set_sequence_auto_mnemonic(bool b);
 #endif
 
+#if defined(WIN32) || defined(Q_OS_WIN)
+// Defined in Windows 11 headers but not in earlier versions.
+#ifndef PROCESS_POWER_THROTTLING_IGNORE_TIMER_RESOLUTION
+#define PROCESS_POWER_THROTTLING_IGNORE_TIMER_RESOLUTION 0x4
+#endif
+
+typedef BOOL (WINAPI *SetProcessInformationType)(
+    HANDLE hProcess,
+    PROCESS_INFORMATION_CLASS ProcessInformationClass,
+    LPVOID ProcessInformation,
+    DWORD ProcessInformationSize
+);
+#endif
+
 //#define DEBUG_SPEED
 
 #ifdef DEBUG_SPEED
@@ -302,6 +317,10 @@ void App::init()
 
 #if defined(WIN32) || defined(Q_OS_WIN)
     HotPlugMonitor::setWinId(winId());
+    
+    // When on Windows 11, disable system timer resolution throttling when
+    // app is minimised, occluded, etc.
+    disableTimerResolutionThrottling();
 #endif
 
     this->setStyleSheet(AppUtil::getStyleSheet("MAIN"));
@@ -332,6 +351,44 @@ bool App::nativeEvent(const QByteArray &eventType, void *message, long *result)
     //qDebug() << Q_FUNC_INFO << eventType;
     return HotPlugMonitor::parseWinEvent(message, result);
 }
+
+void App::disableTimerResolutionThrottling()
+{
+    // On Windows 11, we want it to always honour system timer resolution requests,
+    // because otherwise by default when an application is minimised, or otherwise
+    // non-visible or non-audible to the end-user, Windows may ignore timer
+    // resolution requests and not give a higher resolution than the default system
+    // timer resolution (typically 15.625 ms).
+    
+    // Note: we must resolve the SetProcessInformation API function at run-time
+    // because it does not exist prior to Windows 8. On supported Windows versions
+    // earlier than 11, the call to SetProcessInformation will just fail, which we
+    // can ignore.
+    
+    HMODULE hKernel32 = LoadLibrary(L"kernel32.dll");
+    Q_ASSERT(hKernel32 != NULL); // Shouldn't ever fail because kernel32 already loaded into every process
+
+    // Extra void* cast to avoid -Wcast-function-type warning.
+    SetProcessInformationType pfnSetProcessInformation = (SetProcessInformationType)(void *)GetProcAddress(hKernel32, "SetProcessInformation");
+
+    if (pfnSetProcessInformation != NULL)
+    {
+        PROCESS_POWER_THROTTLING_STATE pwrState = {
+                .Version = PROCESS_POWER_THROTTLING_CURRENT_VERSION,
+                .ControlMask = PROCESS_POWER_THROTTLING_IGNORE_TIMER_RESOLUTION,
+                .StateMask = 0 // Disables timer resolution throttling
+        };
+
+        if (!pfnSetProcessInformation(GetCurrentProcess(), ProcessPowerThrottling, &pwrState, sizeof(pwrState)))
+        {
+            qWarning() << Q_FUNC_INFO << "SetProcessInformation() failed with error" << GetLastError() << "(ignore if Windows version < 11)";
+        }
+    }
+    else
+    {
+        qDebug() << Q_FUNC_INFO << "SetProcessInformation() API does not exist on this version of Windows";
+    }
+}
 #endif
 
 void App::closeEvent(QCloseEvent* e)
@@ -845,10 +902,11 @@ void App::updateFileOpenMenu(QString addRecent)
     if (m_fileOpenMenu == NULL)
     {
         m_fileOpenMenu = new QMenu(this);
-        QString style = "QMenu { background: qlineargradient(x1:0, y1:0, x2:1, y2:1, stop:0 #B9D9E8, stop:1 #A4C0CE);"
+        QPalette p = palette();
+        QString style = QString("QMenu { background: %1;"
                         "border: 1px solid black; font:bold; }"
                         "QMenu::item { background-color: transparent; padding: 5px 10px 5px 10px; border: 1px solid black; }"
-                        "QMenu::item:selected { background-color: #2D8CFF; }";
+                        "QMenu::item:selected { background-color: #2D8CFF; }").arg(p.color(QPalette::Window).name());
         m_fileOpenMenu->setStyleSheet(style);
         connect(m_fileOpenMenu, SIGNAL(triggered(QAction*)),
                 this, SLOT(slotRecentFileClicked(QAction*)));
@@ -1452,6 +1510,9 @@ QFile::FileError App::saveXML(const QString& fileName)
     /* End the document and close all the open elements */
     doc.writeEndDocument();
     file.close();
+#ifdef Q_OS_UNIX
+    sync();
+#endif
 
     // Save to actual requested file name
     QFile currFile(fileName);
