@@ -63,6 +63,7 @@ private:
     void fillAnimationCombo();
     void fillImageAnimationCombo();
     void updateExtraOptions();
+    void updateColorOptions();
     void updateColors();
     void resetProperties(QLayoutItem *item);
     void displayProperties(RGBScript *script);
@@ -77,9 +78,15 @@ private slots:
     void slotFixtureGroupActivated(int index);
     void slotBlendModeChanged(int index);
     void slotControlModeChanged(int index);
-    void slotStartColorButtonClicked();
-    void slotEndColorButtonClicked();
-    void slotResetEndColorButtonClicked();
+    void slotMtxColor1ButtonClicked();
+    void slotMtxColor2ButtonClicked();
+    void slotResetMtxColor2ButtonClicked();
+    void slotMtxColor3ButtonClicked();
+    void slotResetMtxColor3ButtonClicked();
+    void slotMtxColor4ButtonClicked();
+    void slotResetMtxColor4ButtonClicked();
+    void slotMtxColor5ButtonClicked();
+    void slotResetMtxColor5ButtonClicked();
 
     void slotTextEdited(const QString& text);
     void slotFontButtonClicked();
@@ -115,7 +122,7 @@ private slots:
     void slotSaveToSequenceClicked();
     void slotShapeToggle(bool);
 
-    void slotPropertyComboChanged(QString value);
+    void slotPropertyComboChanged(int index);
     void slotPropertySpinChanged(int value);
     void slotPropertyDoubleSpinChanged(double value);
     void slotPropertyEditChanged(QString text);
