@@ -33,9 +33,9 @@ class QXmlStreamWriter;
  * @{
  */
 
-#define KXMLQLCVCFramePageShortcut       QString("Shortcut")
-#define KXMLQLCVCFramePageShortcutPage   QString("Page")
-#define KXMLQLCVCFramePageShortcutName   QString("Name")
+#define KXMLQLCVCFramePageShortcut       QStringLiteral("Shortcut")
+#define KXMLQLCVCFramePageShortcutPage   QStringLiteral("Page")
+#define KXMLQLCVCFramePageShortcutName   QStringLiteral("Name")
 
 class VCFramePageShortcut
 {
