@@ -182,8 +182,9 @@ void VCMatrixPresetSelection::displayProperties(RGBScript *script)
 void VCMatrixPresetSelection::slotUpdatePresetProperties()
 {
     resetProperties(m_propertiesLayout->layout());
-    RGBScript selScript = m_doc->rgbScriptsCache()->script(m_presetCombo->currentText());
-    displayProperties(&selScript);
+    RGBScript* selScript = m_doc->rgbScriptsCache()->script(m_presetCombo->currentText());
+    displayProperties(selScript);
+    delete selScript;
 }
 
 void VCMatrixPresetSelection::slotPropertyComboChanged(int index)
@@ -224,7 +225,7 @@ QString VCMatrixPresetSelection::selectedPreset()
     return m_presetCombo->currentText();
 }
 
-QHash<QString, QString> VCMatrixPresetSelection::customizedProperties()
+QMap<QString, QString> VCMatrixPresetSelection::customizedProperties()
 {
     return m_properties;
 }
