@@ -24,9 +24,6 @@
 #include "vcspeeddialfunction.h"
 #include "function.h"
 
-#define KXMLQLCSequenceSceneValues "Values"
-#define KXMLQLCStepNote "Note"
-
 VCSpeedDialFunction::VCSpeedDialFunction(quint32 aFid, SpeedMultiplier aFadeIn,
                                          SpeedMultiplier aFadeOut, SpeedMultiplier aDuration)
     : functionId(aFid)
