@@ -685,11 +685,12 @@ QSharedPointer<QLCInputSource> VCWidget::inputSource(quint8 id) const
 
 void VCWidget::remapInputSources(int pgNum)
 {
-    foreach (quint8 s, m_inputs.keys())
+    QHash <quint8, QSharedPointer<QLCInputSource> >::iterator it = m_inputs.begin();
+    for (; it != m_inputs.end(); it++)
     {
-        QSharedPointer<QLCInputSource> src(m_inputs.value(s));
+        const QSharedPointer<QLCInputSource>& src(it.value());
         src->setPage(pgNum);
-        setInputSource(src, s);
+        setInputSource(src, it.key());
     }
 }
 
@@ -734,7 +735,7 @@ void VCWidget::slotInputProfileChanged(quint32 universe, const QString &profileN
 
     QLCInputProfile *profile = m_doc->inputOutputMap()->profile(profileName);
 
-    foreach (QSharedPointer<QLCInputSource> const& source, m_inputs.values())
+    foreach (QSharedPointer<QLCInputSource> const& source, m_inputs)
     {
         if (!source.isNull() && source->universe() == universe)
         {
