@@ -227,7 +227,7 @@ VCXYPadProperties::~VCXYPadProperties()
     QSettings settings;
     settings.setValue(SETTINGS_GEOMETRY, saveGeometry());
     m_doc->masterTimer()->unregisterDMXSource(this);
-    foreach (QSharedPointer<GenericFader> fader, m_fadersMap.values())
+    foreach (QSharedPointer<GenericFader> fader, m_fadersMap)
     {
         if (!fader.isNull())
             fader->requestDelete();
@@ -884,7 +884,7 @@ void VCXYPadProperties::slotMoveUpPresetClicked()
     quint8 newID = moveUpPreset(ctlID);
     updatePresetsTree();
 
-    //select item on new position. User can make multiple move up/down without need to select item everytime.
+    //select item on new position. User can make multiple move up/down without need to select item every time.
     selectItemOnPresetsTree(newID);
 }
 
@@ -897,7 +897,7 @@ void VCXYPadProperties::slotMoveDownPresetClicked()
     quint8 newID =moveDownPreset(ctlID);
     updatePresetsTree();
 
-    //select item on new position. User can make multiple move up/down without need to select item everytime.
+    //select item on new position. User can make multiple move up/down without need to select item every time.
     selectItemOnPresetsTree(newID);
 }
 
