@@ -91,9 +91,15 @@ function connect() {
       setCueButtonStyle(msgParams[0], msgParams[2], msgParams[3], msgParams[4], msgParams[5]);
     } else if (msgParams[1] === "MATRIX_SLIDER") {
       setMatrixSliderValue(msgParams[0], msgParams[2]);
-    } else if (msgParams[1] === "MATRIX_START_COLOR") {
+    } else if (msgParams[1] === "MATRIX_COLOR_1") {
       setMatrixStartColorValue(msgParams[0], msgParams[2]);
-    } else if (msgParams[1] === "MATRIX_END_COLOR") {
+    } else if (msgParams[1] === "MATRIX_COLOR_2") {
+      setMatrixEndColorValue(msgParams[0], msgParams[2]);
+    } else if (msgParams[1] === "MATRIX_COLOR_3") {
+      setMatrixEndColorValue(msgParams[0], msgParams[2]);
+    } else if (msgParams[1] === "MATRIX_COLOR_4") {
+      setMatrixEndColorValue(msgParams[0], msgParams[2]);
+    } else if (msgParams[1] === "MATRIX_COLOR_5") {
       setMatrixEndColorValue(msgParams[0], msgParams[2]);
     } else if (msgParams[1] === "MATRIX_COMBO") {
       setMatrixComboValue(msgParams[0], msgParams[2]);
